# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sender.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csender.proto\x12\x06sender\"9\n\x12SendMessageRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x15\n\x13SendMessageResponse2R\n\x06Sender\x12H\n\x0bSendMessage\x12\x1a.sender.SendMessageRequest\x1a\x1b.sender.SendMessageResponse\"\x00\x42$Z\"gitlab.ozon.dev/Zulbukharov/senderb\x06proto3')



_SENDMESSAGEREQUEST = DESCRIPTOR.message_types_by_name['SendMessageRequest']
_SENDMESSAGERESPONSE = DESCRIPTOR.message_types_by_name['SendMessageResponse']
SendMessageRequest = _reflection.GeneratedProtocolMessageType('SendMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGEREQUEST,
  '__module__' : 'sender_pb2'
  # @@protoc_insertion_point(class_scope:sender.SendMessageRequest)
  })
_sym_db.RegisterMessage(SendMessageRequest)

SendMessageResponse = _reflection.GeneratedProtocolMessageType('SendMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGERESPONSE,
  '__module__' : 'sender_pb2'
  # @@protoc_insertion_point(class_scope:sender.SendMessageResponse)
  })
_sym_db.RegisterMessage(SendMessageResponse)

_SENDER = DESCRIPTOR.services_by_name['Sender']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"gitlab.ozon.dev/Zulbukharov/sender'
  _SENDMESSAGEREQUEST._serialized_start=24
  _SENDMESSAGEREQUEST._serialized_end=81
  _SENDMESSAGERESPONSE._serialized_start=83
  _SENDMESSAGERESPONSE._serialized_end=104
  _SENDER._serialized_start=106
  _SENDER._serialized_end=188
# @@protoc_insertion_point(module_scope)
